brightness_volume_manager library
Created by: Minas Chalise 2025 Jan 31
A library that provides an interface for managing the device's brightness and volume settings.
This library allows you to get and set the screen brightness and volume levels, as well as control whether the screen should stay on.
Classes
- BrightnessVolumeManager
- Manages device brightness and volume settings.
- SwipeManager
- A customizable widget that allows vertical or horizontal swipe interaction.
Enums
- SlideDirection
- Enum to define the slide direction of the swipe manager.
Typedefs
- ChangeCallback = void Function(double newValue, double oldValue)
- Callback function type to handle value changes during the swipe.
- ChildBuilder = Widget Function(BuildContext context, double value)
- Function type to build child widgets dynamically based on the swipe value.
- FinishCallback = void Function(double value)
- Callback function type to handle the final value when swipe ends.